import { ExtendedTablePropsV2, ExtendedTableV2 } from './extended-table-v2';
import { Construct } from 'constructs';
import { Capacity } from 'aws-cdk-lib/aws-dynamodb';
import { GlobalSecondaryIndexPropsV2 } from 'aws-cdk-lib/aws-dynamodb/lib/table-v2';
type StandardGlobalSecondaryIndexPropsV2OmitFields = 'partitionKey' | 'sortKey' | 'indexName';
type StandardGlobalSecondaryIndexPropsV2 = Omit<GlobalSecondaryIndexPropsV2, StandardGlobalSecondaryIndexPropsV2OmitFields>;
type StandardTablePropsV2OmitFields = 'tableName' | 'partitionKey' | 'sortKey' | 'globalSecondaryIndexes';
export interface StandardTablePropsV2 extends Omit<ExtendedTablePropsV2, StandardTablePropsV2OmitFields> {
    /**
     * Setting this to true will suppress the creation of default tags on resources
     * created by this construct. Default is false.
     *
     * @default - false
     */
    readonly suppressTagging?: boolean;
    /**
     * Creates additional global secondary indexes on the table with the partition key Gs#Pk and sort key Gs#Sk of string types. Default is 1.
     * Be aware you may only add one index at a time if the table already exists. This is a limitation of the DynamoDB API.
     *
     * @default 1
     */
    readonly globalSecondaryIndexes?: number;
    /**
     * The default read capacity for secondary global indexes. If you want per index settings, use addGlobalSecondaryIndex and set globalSecondaryIndexes to 0.
     *
     * Can only be provided if billingMode is Provisioned.
     *
     * @default is to inherit from the primary table
     */
    readonly globalSecondaryIndexReadCapacity?: Capacity;
    /**
     * The default read capacity for secondary global indexes. If you want per index settings, use addGlobalSecondaryIndex and set globalSecondaryIndexes to 0.
     *
     * Can only be provided if billingMode is Provisioned.
     *
     * @default is to inherit from the primary table
     */
    readonly globalSecondaryIndexWriteCapacity?: Capacity;
}
/**
 * Standard DynamoDB Table V2 with a defined primary key and sort key.
 */
export declare class StandardTableV2 extends ExtendedTableV2 {
    protected secondaryIndexCount: number;
    constructor(scope: Construct, id: string, props?: StandardTablePropsV2);
    /**
     * Add a global secondary index of table.
     *
     * @param props the property of global secondary index
     */
    addGlobalSecondaryIndex(props: StandardGlobalSecondaryIndexPropsV2): void;
}
export {};
