"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardTable = void 0;
const extended_table_1 = require("./extended-table");
const aws_dynamodb_1 = require("aws-cdk-lib/aws-dynamodb");
/**
 * Standard DynamoDB table with a defined primary key, sort key and secondary index. This
 * class is intended to fit most development use cases. Where this class does not meet
 * your requirements, use ExtendedTable directly.
 */
class StandardTable extends extended_table_1.ExtendedTable {
    constructor(scope, id, props) {
        var _a, _b;
        const { globalSecondaryIndexes, ...rest } = props !== null && props !== void 0 ? props : {};
        super(scope, id, {
            timeToLiveAttribute: props === null || props === void 0 ? void 0 : props.timeToLiveAttribute,
            partitionKey: {
                name: 'Pk',
                type: aws_dynamodb_1.AttributeType.STRING,
            },
            sortKey: {
                name: 'Sk',
                type: aws_dynamodb_1.AttributeType.STRING,
            },
            ...rest,
            billingMode: (_a = props === null || props === void 0 ? void 0 : props.billingMode) !== null && _a !== void 0 ? _a : aws_dynamodb_1.BillingMode.PAY_PER_REQUEST,
            deletionProtection: (_b = props === null || props === void 0 ? void 0 : props.deletionProtection) !== null && _b !== void 0 ? _b : true,
        });
        this.secondaryIndexCount = globalSecondaryIndexes !== null && globalSecondaryIndexes !== void 0 ? globalSecondaryIndexes : 1;
        for (let i = 0; i < this.secondaryIndexCount; i++) {
            this.addGlobalSecondaryIndex({
                readCapacity: props === null || props === void 0 ? void 0 : props.readCapacity,
                writeCapacity: props === null || props === void 0 ? void 0 : props.writeCapacity,
            });
        }
    }
    /**
     * Add a global secondary index of table.
     *
     * @param props the property of global secondary index
     */
    addGlobalSecondaryIndex(props) {
        this.secondaryIndexCount++;
        const indexName = `Gs${this.secondaryIndexCount}`;
        super.addGlobalSecondaryIndex({
            indexName,
            partitionKey: {
                name: `Gs${this.secondaryIndexCount}Pk`,
                type: aws_dynamodb_1.AttributeType.STRING,
            },
            sortKey: {
                name: `Gs${this.secondaryIndexCount + 1}Sk`,
                type: aws_dynamodb_1.AttributeType.STRING,
            },
            ...props,
        });
        if (this.tableAlarms) {
            this.tableAlarms.addGlobalSecondaryIndexMonitoring(indexName);
        }
    }
}
exports.StandardTable = StandardTable;
//# sourceMappingURL=standard-table.js.map