import { Construct } from 'constructs/lib/construct';
import { CfnRuleGroup, CfnWebACL } from 'aws-cdk-lib/aws-wafv2';
import { RetentionDays } from 'aws-cdk-lib/aws-logs';
import { ExtendedConstruct } from '../../aws-cdk';
export type cloudFrontBlockMode = 'count' | 'active';
/**
 * Properties for CloudFrontSecurityBaselineWebAcl.
 */
export interface CloudFrontSecurityBaselineWebAclProps {
    /**
     * The mode of the rule group. To Block or to Count. By default it is set to count.
     */
    readonly mode?: cloudFrontBlockMode;
    /**
     * The name of the webAcl.
     */
    readonly webAclName?: string;
    /**
     * The name of the rule group.
     */
    readonly name?: string;
    /**
     * The number of days log events are kept in CloudWatch Logs. Default is 1 year.
     */
    readonly logRetention?: RetentionDays;
    /**
     * The country codes to match against.
     */
    readonly countryCodes: string[];
    /**
     * The string to search for in the request.
     */
    readonly searchString: string;
    /**
     * This is the limit for country based rate based rule.
     */
    readonly uriCountryRuleLimit: number;
    /**
     * The action to take on the URI country rule.
     */
    readonly uriCountryAction?: 'count' | 'block';
    /**
     * The limit for the rate based rule.
     */
    readonly rateBasedRuleLimit: number;
}
/**
 * Creates a rule group and web ACL for CloudFront distributions to use.
 */
export declare class CloudFrontSecurityBaselineWebAcl extends ExtendedConstruct {
    readonly ruleGroup: CfnRuleGroup;
    readonly webAcl: CfnWebACL;
    constructor(scope: Construct, id: string, props?: CloudFrontSecurityBaselineWebAclProps);
}
