"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CloudFrontSecurityBaselineWebAcl = void 0;
const aws_wafv2_1 = require("aws-cdk-lib/aws-wafv2");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const aws_cdk_1 = require("../../aws-cdk");
/**
 * Creates a rule group and web ACL for CloudFront distributions to use.
 */
class CloudFrontSecurityBaselineWebAcl extends aws_cdk_1.ExtendedConstruct {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        super(scope, id);
        this.ruleGroup = new aws_wafv2_1.CfnRuleGroup(this, 'RuleGroup', {
            name: (_a = props === null || props === void 0 ? void 0 : props.name) !== null && _a !== void 0 ? _a : 'SecurityBaselineRuleGroup',
            scope: 'CLOUDFRONT',
            capacity: 500,
            visibilityConfig: {
                cloudWatchMetricsEnabled: true,
                metricName: 'SecurityBaselineRuleGroupMetric',
                sampledRequestsEnabled: true,
            },
            rules: [
                {
                    name: 'UriCountryBased',
                    priority: 1,
                    action: {
                        [(_b = props === null || props === void 0 ? void 0 : props.uriCountryAction) !== null && _b !== void 0 ? _b : 'count']: {},
                    },
                    statement: {
                        rateBasedStatement: {
                            limit: (_c = props === null || props === void 0 ? void 0 : props.uriCountryRuleLimit) !== null && _c !== void 0 ? _c : 200,
                            aggregateKeyType: 'IP',
                            evaluationWindowSec: 300,
                            scopeDownStatement: {
                                andStatement: {
                                    statements: [
                                        {
                                            byteMatchStatement: {
                                                searchString: (_d = props === null || props === void 0 ? void 0 : props.searchString) !== null && _d !== void 0 ? _d : '/api/login',
                                                fieldToMatch: {
                                                    uriPath: {},
                                                },
                                                positionalConstraint: 'EXACTLY',
                                                textTransformations: [
                                                    {
                                                        priority: 0,
                                                        type: 'NONE',
                                                    },
                                                ],
                                            },
                                        },
                                        {
                                            geoMatchStatement: {
                                                countryCodes: (_e = props === null || props === void 0 ? void 0 : props.countryCodes) !== null && _e !== void 0 ? _e : ['CN', 'RU'],
                                            },
                                        },
                                    ],
                                },
                            },
                        },
                    },
                    visibilityConfig: {
                        sampledRequestsEnabled: true,
                        cloudWatchMetricsEnabled: true,
                        metricName: 'uri-country-based',
                    },
                },
                {
                    name: 'LoginRateLimitRule',
                    priority: 0, // Ensure priorities do not overlap with existing rules
                    action: {
                        block: {},
                    },
                    statement: {
                        rateBasedStatement: {
                            limit: (_f = props === null || props === void 0 ? void 0 : props.rateBasedRuleLimit) !== null && _f !== void 0 ? _f : 300,
                            aggregateKeyType: 'IP',
                            evaluationWindowSec: 300,
                            scopeDownStatement: {
                                byteMatchStatement: {
                                    searchString: (_g = props === null || props === void 0 ? void 0 : props.searchString) !== null && _g !== void 0 ? _g : '/api/login',
                                    fieldToMatch: {
                                        uriPath: {},
                                    },
                                    textTransformations: [
                                        {
                                            priority: 0,
                                            type: 'NONE',
                                        },
                                    ],
                                    positionalConstraint: 'STARTS_WITH',
                                },
                            },
                        },
                    },
                    visibilityConfig: {
                        sampledRequestsEnabled: true,
                        cloudWatchMetricsEnabled: true,
                        metricName: 'login-rate-limit-rule',
                    },
                },
            ],
        });
        this.webAcl = new aws_wafv2_1.CfnWebACL(this, 'WebAcl', {
            name: (_h = props === null || props === void 0 ? void 0 : props.webAclName) !== null && _h !== void 0 ? _h : 'SecurityBaselineWebACL',
            defaultAction: { allow: {} },
            scope: 'CLOUDFRONT',
            visibilityConfig: {
                cloudWatchMetricsEnabled: true,
                metricName: 'globalWebAclMetric',
                sampledRequestsEnabled: true,
            },
            rules: [
                {
                    name: 'AWS-AWSManagedRulesCommonRuleSet',
                    priority: 0,
                    overrideAction: (props === null || props === void 0 ? void 0 : props.mode) === 'active' ? { none: {} } : { count: {} },
                    statement: {
                        managedRuleGroupStatement: {
                            vendorName: 'AWS',
                            name: 'AWSManagedRulesCommonRuleSet',
                        },
                    },
                    visibilityConfig: {
                        cloudWatchMetricsEnabled: true,
                        metricName: 'AWSManagedRulesCommonRuleSetMetric',
                        sampledRequestsEnabled: true,
                    },
                },
                {
                    name: 'SecurityBaselineRuleGroup',
                    priority: 1,
                    overrideAction: (props === null || props === void 0 ? void 0 : props.mode) === 'active' ? { none: {} } : { count: {} },
                    statement: {
                        ruleGroupReferenceStatement: {
                            arn: this.ruleGroup.attrArn,
                        },
                    },
                    visibilityConfig: {
                        cloudWatchMetricsEnabled: true,
                        metricName: 'SecurityBaselineRuleGroupMetric',
                        sampledRequestsEnabled: true,
                    },
                },
                {
                    name: 'AWS-AWSManagedRulesKnownBadInputsRuleSet',
                    priority: 2,
                    overrideAction: (props === null || props === void 0 ? void 0 : props.mode) === 'active' ? { none: {} } : { count: {} },
                    statement: {
                        managedRuleGroupStatement: {
                            vendorName: 'AWS',
                            name: 'AWSManagedRulesKnownBadInputsRuleSet',
                        },
                    },
                    visibilityConfig: {
                        cloudWatchMetricsEnabled: true,
                        metricName: 'AWSManagedRulesKnownBadInputsRuleSetMetric',
                        sampledRequestsEnabled: true,
                    },
                },
                {
                    name: 'AWS-AWSManagedRulesAnonymousIpList',
                    priority: 3,
                    overrideAction: (props === null || props === void 0 ? void 0 : props.mode) === 'active' ? { none: {} } : { count: {} },
                    statement: {
                        managedRuleGroupStatement: {
                            vendorName: 'AWS',
                            name: 'AWSManagedRulesAnonymousIpList',
                        },
                    },
                    visibilityConfig: {
                        cloudWatchMetricsEnabled: true,
                        metricName: 'AWSManagedRulesAnonymousIpListMetric',
                        sampledRequestsEnabled: true,
                    },
                },
                {
                    name: 'AWS-AWSManagedRulesAmazonIpReputationList',
                    priority: 4,
                    overrideAction: (props === null || props === void 0 ? void 0 : props.mode) === 'active' ? { none: {} } : { count: {} },
                    statement: {
                        managedRuleGroupStatement: {
                            vendorName: 'AWS',
                            name: 'AWSManagedRulesAmazonIpReputationList',
                        },
                    },
                    visibilityConfig: {
                        cloudWatchMetricsEnabled: true,
                        metricName: 'AWSManagedRulesAmazonIpReputationListMetric',
                        sampledRequestsEnabled: true,
                    },
                },
            ],
        });
        this.webAcl.addPropertyOverride('Rules.3.Statement.ManagedRuleGroupStatement.RuleActionOverrides', [{ Name: 'HostingProviderIPList', ActionToUse: { Count: {} } }]);
        const wafLogGroup = new aws_logs_1.LogGroup(this, 'WafLogGroup', {
            logGroupName: `aws-waf-logs-global-waf-acl-logs-${this.node.addr}`,
            retention: (_j = props === null || props === void 0 ? void 0 : props.logRetention) !== null && _j !== void 0 ? _j : aws_logs_1.RetentionDays.ONE_YEAR,
        });
        new aws_wafv2_1.CfnLoggingConfiguration(this, 'LoggingConfig', {
            resourceArn: this.webAcl.attrArn,
            logDestinationConfigs: [wafLogGroup.logGroupArn],
        });
    }
}
exports.CloudFrontSecurityBaselineWebAcl = CloudFrontSecurityBaselineWebAcl;
//# sourceMappingURL=cloud-front-security-baseline-web-acl.js.map